==> CGAL-5.6.1-doc_html.tar.xz: doc_html/Ridges_3/group__PkgRidges3Ref.js <==
var group__PkgRidges3Ref =
[
    [ "Enums", "group__PkgRidges3Enums.html", "group__PkgRidges3Enums" ],
    [ "Ridge_approximation", "classCGAL_1_1Ridge__approximation.html", [
      [ "Ridge_approximation", "classCGAL_1_1Ridge__approximation.html#aa037edd340871bedc7356ed71d4671bc", null ],
      [ "compute_crest_ridges", "classCGAL_1_1Ridge__approximation.html#ad0ee150d6563444483c0c06dd346df65", null ],
      [ "compute_max_ridges", "classCGAL_1_1Ridge__approximation.html#a61b39f380ed5ec620f7fdcc577d31e00", null ],
      [ "compute_min_ridges", "classCGAL_1_1Ridge__approximation.html#a4577c3ec620b7f3331e2e42f398de8e6", null ]
    ] ],
    [ "Ridge_line", "classCGAL_1_1Ridge__line.html", [
      [ "FT", "classCGAL_1_1Ridge__line.html#ac1d3d3563c9692fd7b07442514fba00f", null ],
      [ "halfedge_descriptor", "classCGAL_1_1Ridge__line.html#a89fa1164092c3b2f4cc8b38e5f6f6110", null ],
      [ "Ridge_halfedge", "classCGAL_1_1Ridge__line.html#ac78ee05739bf27bb48db82e01a216891", null ],
      [ "Ridge_line", "classCGAL_1_1Ridge__line.html#ae74deea7b713f60c9ad6046958ae0300", null ],
      [ "line", "classCGAL_1_1Ridge__line.html#a72b4732b1f6dcb5ed809ad87dc9007ef", null ],
      [ "line_type", "classCGAL_1_1Ridge__line.html#ab06b16c95ab22264946db8889b4054fc", null ],
      [ "sharpness", "classCGAL_1_1Ridge__line.html#adcfa996e1ac13a86c48578a6d9197cbc", null ],
      [ "strength", "classCGAL_1_1Ridge__line.html#aec762f9a81909501df66803e64699a55", null ],
      [ "operator<<", "classCGAL_1_1Ridge__line.html#a3ea17a18ec517b62e319e2b42129b8c4", null ]
    ] ],
    [ "Umbilic_approximation", "classCGAL_1_1Umbilic__approximation.html", [
      [ "FT", "classCGAL_1_1Umbilic__approximation.html#af09b7d753f3858ca279678f66308b399", null ],
      [ "Umbilic_approximation", "classCGAL_1_1Umbilic__approximation.html#ae9fdf34babb6b62c3a001c11d17a09a4", null ],
      [ "compute", "classCGAL_1_1Umbilic__approximation.html#a7c0c937739e4d842cf00d3babcd67305", null ]
    ] ],
    [ "Umbilic", "classCGAL_1_1Umbilic.html", [
      [ "halfedge_descriptor", "classCGAL_1_1Umbilic.html#a26f971b2fd000202edd170ba3dcbb9eb", null ],
      [ "vertex_descriptor", "classCGAL_1_1Umbilic.html#acfc48c24bbb04e4ab8dc4380985bfe83", null ],
      [ "contour_list", "classCGAL_1_1Umbilic.html#a720215425905f9feb0942a575a3bc5ad", null ],
      [ "umbilic_type", "classCGAL_1_1Umbilic.html#ab0c4b9144495f70ca0c6f1a7ed0f7bfe", null ],
      [ "vertex", "classCGAL_1_1Umbilic.html#abc11cc97780f5b301474756dc7cf7490", null ],
      [ "operator<<", "classCGAL_1_1Umbilic.html#ae5a7c264e8dd32252572970b1734bff4", null ]
    ] ],
    [ "compute_crest_ridges", "group__PkgRidges3Ref.html#ga160ff11edf5b6fd969f94461703d4e35", null ],
    [ "compute_max_ridges", "group__PkgRidges3Ref.html#gacbcb335296cafd49ca33420d2fea8c24", null ],
    [ "compute_min_ridges", "group__PkgRidges3Ref.html#ga03c751ca758e75a4e00c9c60843e0eb5", null ],
    [ "compute_umbilics", "group__PkgRidges3Ref.html#gaec8861e49a5cddc02ac9723f8f2b88ba", null ]
];

==> CGAL-6.1-doc_html.tar.xz: doc_html/Ridges_3/group__PkgRidges3Ref.js <==
var group__PkgRidges3Ref =
[
    [ "Enums", "group__PkgRidges3Enums.html", "group__PkgRidges3Enums" ],
    [ "CGAL::Ridge_approximation< TriangleMesh, VertexFTMap, VertexVectorMap >", "classCGAL_1_1Ridge__approximation.html", [
      [ "Ridge_approximation", "classCGAL_1_1Ridge__approximation.html#aa037edd340871bedc7356ed71d4671bc", null ],
      [ "compute_crest_ridges", "classCGAL_1_1Ridge__approximation.html#ad0ee150d6563444483c0c06dd346df65", null ],
      [ "compute_max_ridges", "classCGAL_1_1Ridge__approximation.html#a61b39f380ed5ec620f7fdcc577d31e00", null ],
      [ "compute_min_ridges", "classCGAL_1_1Ridge__approximation.html#a4577c3ec620b7f3331e2e42f398de8e6", null ]
    ] ],
    [ "CGAL::Ridge_line< TriangleMesh >", "classCGAL_1_1Ridge__line.html", [
      [ "FT", "classCGAL_1_1Ridge__line.html#ac1d3d3563c9692fd7b07442514fba00f", null ],
      [ "halfedge_descriptor", "classCGAL_1_1Ridge__line.html#a89fa1164092c3b2f4cc8b38e5f6f6110", null ],
      [ "Ridge_halfedge", "classCGAL_1_1Ridge__line.html#ac78ee05739bf27bb48db82e01a216891", null ],
      [ "Ridge_line", "classCGAL_1_1Ridge__line.html#ae74deea7b713f60c9ad6046958ae0300", null ],
      [ "line", "classCGAL_1_1Ridge__line.html#ac93539578113c3670c6e3ac1b7f2f02e", null ],
      [ "line_type", "classCGAL_1_1Ridge__line.html#ab06b16c95ab22264946db8889b4054fc", null ],
      [ "sharpness", "classCGAL_1_1Ridge__line.html#adcfa996e1ac13a86c48578a6d9197cbc", null ],
      [ "strength", "classCGAL_1_1Ridge__line.html#aec762f9a81909501df66803e64699a55", null ],
      [ "operator<<", "classCGAL_1_1Ridge__line.html#a3ea17a18ec517b62e319e2b42129b8c4", null ]
    ] ],
    [ "CGAL::Umbilic_approximation< TriangleMesh, VertexFTMap, VertexVectorMap >", "classCGAL_1_1Umbilic__approximation.html", [
      [ "FT", "classCGAL_1_1Umbilic__approximation.html#af09b7d753f3858ca279678f66308b399", null ],
      [ "Umbilic_approximation", "classCGAL_1_1Umbilic__approximation.html#ae9fdf34babb6b62c3a001c11d17a09a4", null ],
      [ "compute", "classCGAL_1_1Umbilic__approximation.html#a7c0c937739e4d842cf00d3babcd67305", null ]
    ] ],
    [ "CGAL::Umbilic< TriangleMesh >", "classCGAL_1_1Umbilic.html", [
      [ "halfedge_descriptor", "classCGAL_1_1Umbilic.html#a26f971b2fd000202edd170ba3dcbb9eb", null ],
      [ "vertex_descriptor", "classCGAL_1_1Umbilic.html#acfc48c24bbb04e4ab8dc4380985bfe83", null ],
      [ "contour_list", "classCGAL_1_1Umbilic.html#a5e4d5aeb6579d18e107c09822e0cca03", null ],
      [ "umbilic_type", "classCGAL_1_1Umbilic.html#ab0c4b9144495f70ca0c6f1a7ed0f7bfe", null ],
      [ "vertex", "classCGAL_1_1Umbilic.html#abc11cc97780f5b301474756dc7cf7490", null ],
      [ "operator<<", "classCGAL_1_1Umbilic.html#ae5a7c264e8dd32252572970b1734bff4", null ]
    ] ],
    [ "CGAL::compute_crest_ridges", "group__PkgRidges3Ref.html#ga160ff11edf5b6fd969f94461703d4e35", null ],
    [ "CGAL::compute_max_ridges", "group__PkgRidges3Ref.html#gacbcb335296cafd49ca33420d2fea8c24", null ],
    [ "CGAL::compute_min_ridges", "group__PkgRidges3Ref.html#ga03c751ca758e75a4e00c9c60843e0eb5", null ],
    [ "CGAL::compute_umbilics", "group__PkgRidges3Ref.html#gaec8861e49a5cddc02ac9723f8f2b88ba", null ]
];
